import { Directive, ElementRef, Input, Output, EventEmitter } from '@angular/core';
/**
 * @element ons-select
 * @directive OnsSelect
 * @selector ons-select
 * @description
 *   [en]Angular 2 directive for `<ons-select>` component.[/en]
 *   [ja]`<ons-select>`要素のAngular 2ディレクティブです。[/en]
 * @example
 *   <ons-select>
 *    <option value="basic">Basic</option>
 *    <option value="material">Material</option>
 *    <option value="underbar">Underbar</option>
 *   </ons-select><br>
 */
var OnsSelect = (function () {
    function OnsSelect(_elementRef) {
        this._elementRef = _elementRef;
        /**
         * @output valueChange
         * @type {string}
         * @desc
         *   [en]Triggers when the value is changed.[/en]
         *   [ja]値が変更された時に発火します。[/ja]
         */
        this._valueChange = new EventEmitter();
        this._boundOnChange = this._onChange.bind(this);
        this._element = _elementRef.nativeElement;
        this._element.addEventListener('change', this._boundOnChange);
    }
    OnsSelect.prototype._onChange = function (event) {
        this._valueChange.emit(this._element.value);
    };
    OnsSelect.prototype.ngOnChanges = function (changeRecord) {
        var value = changeRecord['_value'].currentValue;
        this._element.value = value;
    };
    Object.defineProperty(OnsSelect.prototype, "element", {
        get: function () {
            return this._element;
        },
        enumerable: true,
        configurable: true
    });
    OnsSelect.prototype.ngOnDestroy = function () {
        this._element.removeEventListener('change', this._boundOnChange);
        this._element = null;
    };
    return OnsSelect;
}());
export { OnsSelect };
OnsSelect.decorators = [
    { type: Directive, args: [{
                selector: 'ons-select'
            },] },
];
/** @nocollapse */
OnsSelect.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
OnsSelect.propDecorators = {
    '_value': [{ type: Input, args: ['value',] },],
    '_valueChange': [{ type: Output, args: ['valueChange',] },],
};
//# sourceMappingURL=ons-select.js.map